#
# spec file for package python3-tables
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-tables
Version:        3.2.2
Release:        2.16
Summary:        Hierarchical datasets for Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://www.pytables.org/
Source0:        https://pypi.python.org/packages/source/t/tables/tables-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hdf5-devel >= 1.8.9
BuildRequires:  libbz2-devel
BuildRequires:  lzo-devel
BuildRequires:  python3-2to3
BuildRequires:  python3-Cython >= 0.13
BuildRequires:  python3-blosc
BuildRequires:  python3-devel
BuildRequires:  python3-numexpr >= 2.4
BuildRequires:  python3-numpy-devel >= 1.7.1
BuildRequires:  python3-setuptools
Requires:       hdf5 >= 1.8.9
Requires:       python3-blosc
Requires:       python3-numexpr >= 2.4
Requires:       python3-numpy >= 1.7.1
Recommends:     bzip2
Recommends:     lzo
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
PyTables is a package for managing hierarchical datasets and
designed to efficently cope with extremely large amounts of
data. PyTables is built on top of the HDF5 library and the
NumPy package and features an object-oriented interface
that, combined with C-code generated from Pyrex sources,
makes of it a fast, yet extremely easy to use tool for
interactively save and retrieve large amounts of data.

%package doc
Summary:        Documentation for %{name}
Group:          Development/Languages/Python

%description doc
Documentation and help files for %{name}

%prep
%setup -n tables-%{version}

%build
CFLAGS="%{optflags} -fno-strict-aliasing" python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
%fdupes -s %{buildroot}%{python3_sitearch}
mv %{buildroot}%{_bindir}/ptdump %{buildroot}%{_bindir}/ptdump-%{py3_ver}
mv %{buildroot}%{_bindir}/ptrepack %{buildroot}%{_bindir}/ptrepack-%{py3_ver}
mv %{buildroot}%{_bindir}/pt2to3 %{buildroot}%{_bindir}/pt2to3-%{py3_ver}
mv %{buildroot}%{_bindir}/pttree %{buildroot}%{_bindir}/pttree-%{py3_ver}

%files
%defattr(-,root,root)
%doc ANNOUNCE.txt LICENSE.txt README.rst RELEASE_NOTES.txt THANKS
%{_bindir}/ptdump-%{py3_ver}
%{_bindir}/ptrepack-%{py3_ver}
%{_bindir}/pt2to3-%{py3_ver}
%{_bindir}/pttree-%{py3_ver}
%{python3_sitearch}/tables/
%{python3_sitearch}/tables-%{version}-py%{py3_ver}.egg-info

%files doc
%defattr(-,root,root)
%doc doc/html

%changelog
* Sun Sep 27 2015 arun@gmx.de
- update to version 3.2.2:
  * Fix AssertionError in Row.__init_loop. See gh-477.
  * Fix issues with Cython 0.23. See gh-481.
  * Only run tables.tests.test_basics.UnicodeFilename if the
    filesystem encoding is utf-8. Closes gh-485.
  * Fix missing missing PyErr_Clear. See gh-#486.
  * Fix the C type of some numpy attributes. See gh-494.
  * Cast selection indices to integer. See gh-496.
  * Fix indexesextension._keysort_string. Closes gh-497 and gh-498.
- changes from version 3.2.1.1:
  * Fix permission on distributed source distribution
* Mon Aug 10 2015 arun@gmx.de
- update to version 3.2.1:
  * Fix indexesextension._keysort. Fixes gh-455. Thanks to Andrew Lin.
* Sat May  9 2015 arun@gmx.de
- specfile:
  * updated copyright year
  * removed modname
  * updated source url to pypi
  * add setuptools requirement
  * updated version number requirement for numpy and numexpr
  * README.txt -> README.rst
  * added pttree bin
- update to version 3.2.0:
  * The nrowsinbuf is better computed now for EArray/CArray having a
    small chunkshape in the main dimension. Fixes #285.
  * PyTables should be installable very friendly via pip, including
    NumPy being installed automatically in the unlikely case it is not
    yet installed in the system. Thanks to Andrea Bedini.
  * setup.py has been largely simplified and now it requires
    setuptools. Although we think this is a good step, please keep us
    informed this is breaking some installation in a very bad manner.
  * setup.py now is able to used pkg-config, if available, to locate
    required libraries (hdf5, bzip2, etc.). The use of pkg-config can
    be controlled via setup.py command line flags or via environment
    variables. Please refer to the installation guide (in the User
    Manual) for details. Closes gh-442.
  * It is now possible to create a new node whose parent is a softlink
    to another group (see gh-422). Thanks to Alistair Muldal.
  * link.SoftLink objects no longer need to be explicitly
    dereferenced. Methods and attributes of the linked object are now
    automatically accessed when the user acts on a soft-link (see
    gh-399). Thanks to Alistair Muldal.
  * Now ptrepack recognizes hardlinks and replicates them in the
    output (repacked) file. This saves disk space and makes repacked
    files more conformal to the original one. Closes gh-380.
  * New pttree script for printing HDF5 file contents as a pretty
    ASCII tree (closes gh-400). Thanks to Alistair Muldal.
  * The internal Blosc library has been downgraded to version
    1.4.4. This is in order to still allow using multiple threads
    inside Blosc, even on multithreaded applications (see gh-411,
    gh-412, gh-437 and gh-448).
  * The print_versions() function now also reports the version of
    compression libraries used by Blosc.
  * Now the setup.py tries to use the ‘-march=native’ C flag by
    default. In falls back on ‘-msse2’ if ‘-march=native’ is not
    supported by the compiler. Closes gh-379.
  * Fixed a spurious unicode comparison warning (closes gh-372 and
    gh-373).
  * Improved handling of empty string attributes. In previous versions
    of PyTables empty string were stored as scalar HDF5 attributes
    having size 1 and value ‘0’ (an empty null terminated string). Now
    empty string are stored as HDF5 attributes having zero size
  * Added a new cookbook recipe and a couple of examples for simple
    threading with PyTables.
  * The redundant utilsextension.get_indices() function has been
    eliminated (replaced by slice.indices()). Closes gh-195.
  * Allow negative indices in point selection (closes gh-360)
  * Index wasn’t being used if it claimed there were no
    results. Closes gh-351 (see also gh-353)
  * Atoms and Col types are no longer generated dynamically so now it
    is easier for IDEs and static analysis tool to handle them (closes
    gh-345)
  * The keysort functions in idx-opt.c have been cythonised using
    fused types. The perfomance is mostly unchanged, but the code is
    much more simpler now. Thanks to Andrea Bedini.
  * Small unit tests re-factoring:
    + print_versions() and tests.common.print_heavy() functions
    moved to the tests.common module
    + always use print_versions() when test modules are called as scripts
    + use the unittest2 package in Python 2.6.x
    + removed internal machinery used to replicate unittest2 features
    + always use tests.common.PyTablesTestCase as base class for all test cases
    + code of the old tasts.common.cleanup() function has been moved to tests.common.PyTablesTestCase.tearDown() method
    + new implementation of tests.common.PyTablesTestCase.assertWarns() compatible with the one provided by the standard unittest module in Python >= 3.2
    + use tests.common.PyTablesTestCase.assertWarns() as context manager when appropriate
    + use the unittest.skipIf() decorator when appropriate
    + new :class:tests.comon.TestFileMixin: class
  * Fixed compatibility problems with numpy 1.9 and 1.10-dev (closes
    gh-362 and gh-366)
  * Fixed compatibility with Cython >= 0.20 (closes gh-386 and gh-387)
  * Fixed support for unicode node names in LRU cache (only Python 2
    was affected). Closes gh-367 and gh-369.
  * Fixed support for unicode node titles (only Python 2 was
    affected). Closes gh-370 and gh-374.
  * Fixed a bug that caused the silent truncation of unicode
    attributes containing the ‘0’ character. Closes gh-371.
  * Fixed descr_from_dtype() to work as expected with complex
    types. Closes gh-381.
  * Fixed the tests.test_basics.ThreadingTestCase test case. Closes
    gh-359.
  * Fix incomplete results when performing the same query twice and
    exhausting the second iterator before the first. The first one
    writes incomplete results to seqcache (gh-353)
  * Fix false results potentially going to seqcache if
    tableextension.Row.update() is used during iteration (see gh-353)
  * Fix Column.create_csindex() when there’s NaNs
  * Fixed handling of unicode file names on windows (closes gh-389)
  * No longer not modify sys.argv at import time (closes gh-405)
  * Fixed a performance issue on NFS (closes gh-402)
  * Fixed a nasty problem affecting results of indexed queries. Closes
    gh-319 and probably gh-419 too.
  * Fixed another problem affecting results of indexed queries
    too. Closes gh-441.
  * Replaced "len(xrange(start, stop, step))" -> "len(xrange(0, stop -
    start, step))" to fix issues with large row counts with Python
    2.x. Fixes #447.
  * Cython is not a hard dependency anymore (although developers will
    need it so as to generated the C extension code).
  * The number of threads used by default for numexpr and Blosc
    operation that was set to the number of available cores have been
    reduced to 2. This is a much more reasonable setting for not
    creating too much overhead.
* Thu May  8 2014 toddrme2178@gmail.com
- New version 3.1.1
  - Fixed a critical bug that caused an exception at import time.
    The error was triggered when a bug in long-double detection is detected
    in the HDF5 library (see :issue:`275`) and numpy_ does not expose
    `float96` or `float128`. Closes :issue:`344`.
  - The internal Blosc_ library has been updated to version 1.3.5.
    This fixes a false buffer overrun condition that made c-blosc to fail,
    even if the problem was not real.
- New version 3.1.0
  - New features¶
  - Now PyTables is able to save/restore the default value
    of EnumAtom types.
  - Implemented support for the H5FD_SPLIT driver.
  - New quantization filter: the filter truncates floating point
    data to a specified precision before writing to disk.
    This can significantly improve the performance of compressors.
  - Added new VLArray.get_row_size() method to VLArray for querying
    the number of atoms of a VLArray row. Closes gh-24 and gh-315.
  - The internal Blosc library has been updated to version 1.3.2.
    All new features introduced in the Blosc 1.3.x series, and in
    particular the ability to leverage different compressors within
    Blosc (see the Blosc Release Notes), are now available in
    PyTables via the blosc filter.
  - Improvements¶
  - The node caching mechanism has been completely redesigned to
    be simpler and less dependent from specific behaviours of
    the __del__ method. Now PyTables is compatible with the
    forthcoming Python 3.4. Closes gh-306.
  - PyTables no longer uses shared/cached file handlers.
    This change somewhat improves support for concurrent reading
    allowing the user to safely open the same file in different
    threads for reading (requires HDF5 >= 1.8.7). More details
    about this change can be found in the Backward incompatible
    changes section. See also gh-130, gh-129 gh-292 and gh-216.
  - PyTables is now able to detect and use external installations
    of the Blosc library (closes gh-104). If Blosc is not found in
    the system, and the user do not specify a custom installation
    directory, then it is used an internal copy of the Blosc source
    code.
  - Automatically disable extended float support if a buggy version
    of HDF5 is detected (see also Issues with H5T_NATIVE_LDOUBLE).
  - Documented an unexpected behaviour with string literals in query
    conditions on Python 3 (closes gh-265)
  - The deprecated getopt module has been dropped in favour of
    argparse in all command line utilities (close gh-251)
  - Improved the installation section of the PyTables User’s Guide.
  - instructions for installing PyTables via pip have been added.
  - added a reference to the Anaconda, Canopy and Christoph
    Gohlke suites (closes gh-291)
  - Enabled Travis-CI builds for Python 3.3
  - Tables.read_coordinates() now also works with boolean indices input.
  - Improved compatibility with numpy >= 1.8 (see gh-259)
  - The code of the benchmark programs (bench directory) has been updated.
  - Fixed some warning related to non-unicode file names
    (the Windows bytes API has been deprecated in Python 3.4)
  - Bugs fixed¶
  - Fixed detection of platforms supporting Blosc
  - Fixed a crash that occurred when one attempts to write a numpy array
    to an Atom (closes gh-209 and gh-296)
  - Prevent creation of a table with no columns.
  - Fixed a memory leak that occured when iterating over
    CArray/EArray objects.
  - Make NaN types sort to the end. Closes gh-282 and gh-313
  - Fixed selection on float columns when NaNs are present.
  - Fix computation of the buffer size for iterations on rows.
    The buffers size was overestimated resulting in a MemoryError
    in some cases. Closes gh-316. Thamks to bbudescu.
  - Better check of file open mode. Closes gh-318.
  - The Blosc filter now works correctly together with fletcher32. Closes gh-21.
  - Close the file handle before trying to delete the corresponding file.
    Fixes a test failure on Windows.
  - Use integer division for computing indices (fixes some warning on Windows)
- Use external python3-blosc.  The internal one builds a bad version
  of zlib.
* Mon May  6 2013 highwaystar.ru@gmail.com
- initial python3 package based on 3.0.0
  New features
  - -----------
  * Since this release PyTables provides full support to Python_ 3
  (closes :issue`188`).
  * The entire code base is now more compliant with coding style guidelines
  describe in the PEP8_ (closes :issue:`103` and :issue:`224`).
  See `API changes`_ for more details.
  * Basic support for HDF5 drivers.  Now it is possible to open/create an
  HDF5 file using one of the SEC2, DIRECT, LOG, WINDOWS, STDIO or CORE
  drivers.  Users can also set the main driver parameters (closes
  :issue:`166`).
  Thanks to Michal Slonina.
  * Basic support for in-memory image files.  An HDF5 file can be set from or
  copied into a memory buffer (thanks to Michal Slonina).  This feature is
  only available if PyTables is built against HDF5 1.8.9 or newer.
  Closes :issue:`165` and :issue:`173`.
  * New :meth:`File.get_filesize` method for retrieving the HDF5 file size.
  * Implemented methods to get/set the user block size in a HDF5 file
  (closes :issue:`123`)
  * Improved support for PyInstaller_.  Now it is easier to pack frozen
  applications that use the PyTables package (closes: :issue:`177`).
  Thanks to Stuart Mentzer and Christoph Gohlke.
  * All read methods now have an optional *out* argument that allows to pass a
  pre-allocated array to store data (closes :issue:`192`)
  * Added support for the floating point data types with extended precision
  (Float96, Float128, Complex192 and Complex256).  This feature is only
  available if numpy_ provides it as well.
  Closes :issue:`51` and :issue:`214`.  Many thanks to Andrea Bedini.
  * New :program:`pt2to3` tool is provided to help users to port their
  applications to the new API (see `API changes`_ section).
  Improvements
  - -----------
  * Improved runtime checks on dynamic loading of libraries: meaningful error
  messages are generated in case of failure.
  Also, now PyTables no more alters the system PATH.
  Closes :issue:`178` and :issue:`179` (thanks to Christoph Gohlke).
  * Improved list of search paths for libraries as suggested by Nicholaus
  Halecky (see :issue:`219`).
  * Removed deprecated Cython_ include (.pxi) files. Contents of
  :file:`convtypetables.pxi` have been moved in :file:`utilsextension.pyx`.
  Closes :issue:`217`.
  * The internal Blosc_ library has been upgraded to version 1.2.1.
  * Pre-load the bzip2_ library on windows (closes :issue:`205`)
  * The :meth:`File.get_node` method now accepts unicode paths
  (closes :issue:`203`)
  * Improved compatibility with Cython_ 0.19 (see :issue:`220` and
  :issue:`221`)
  * Improved compatibility with numexpr_ 2.1 (see also :issue:`199` and
  :issue:`241`)
  * Improved compatibility with development versions of numpy_
  (see :issue:`193`)
  * Packaging: since this release the standard tar-ball package no more includes
  the PDF version of the "PyTables User Guide", so it is a little bit smaller
  now.  The complete and pre-build version of the documentation both in HTML
  and PDF format is available on the file `download area`_ on SourceForge.net.
  Closes: :issue:`172`.
  * Now PyTables also uses `Travis-CI`_ as continuous integration service.
  All branches and all pull requests are automatically tested with different
  Python_ versions.  Closes :issue:`212`.
  Other changes
  - ------------
  * PyTables now requires Python 2.6 or newer.
- for api changes check RELEASE_NOTES.txt
